@@ -1,14 +1,16 @@
+import copy
 from collections import namedtuple
 from kaa.filetype.default import defaultmode
 from gappedbuf import re as gre
 from kaa.highlight import Tokenizer, Token, Span, Keywords, EndSection, SingleToken
 from kaa.theme import Theme, Style
+from kaa.command import Commands, command, norec, norerun
+from kaa.keyboard import *
 
 MarkdownThemes = {
     'basic':
         Theme([
             Style('header', 'Blue', None),
-            Style('block', 'Orange', None),
             Style('hr', 'Green', None),
             Style('strong', 'Magenta', None),
             Style('emphasis', 'Blue', None),
@@ -78,14 +80,28 @@ class ImageToken(LinkToken):
     def re_start(self):
         return r'!\['
 
+class MDInline(Span):
+    WS = ' \t\r\n'
+    
+    def on_start(self, tokenizer, doc, pos, match):
+        if ((pos >= doc.endpos()-1) or
+            (doc.gettext(pos+1, pos+2) in self.WS)):
 
+            yield pos, pos+1, tokenizer.nulltoken
+            return pos+1, None, False
+                
+        ret = yield from super().on_start(tokenizer, doc, pos, match)
+        return ret
+
+    
+HEADERS = r'=-'
 def build_tokenizer():
     MARKDOWNTOKENS = namedtuple('markdowntokens', 
-                            ['escape', 'header1', 'header2', 'codeblock', 
-                             'hr', 'link', 'image', 'strong1', 'strong2', 
+                            ['escape', 'header1', 'header2',
+                             'hr', 'link', 'image', 
+                             'strong1', 'strong2', 
                              'emphasis1', 'emphasis2', 'code1', 'code2'])
 
-    HEADERS = r'=-'
     return Tokenizer(MARKDOWNTOKENS(
             # escape
             SingleToken('md-escape', 'default', [r'\\.']),
@@ -95,9 +111,6 @@ def build_tokenizer():
                     [r'^.+\n(?P<H1>[{}])(?P=H1)+$'.format(HEADERS)]),
             SingleToken('md-header2', 'header', [r'^\#{1,6}.*$']),
 
-            # code block
-            SingleToken('md-codeblock', 'literal', [r'^(\t+|\ {4,}).*$']),
-            
             # hr
             SingleToken('md-hr', 'hr', [r'^(\-{3,}|_{3,}|\*{3,})$']),
             
@@ -108,26 +121,101 @@ def build_tokenizer():
             ImageToken('md-image', 'reference'),
             
             # strong
-            Span('md-strong1', 'strong', r'\*\*', r'\*\*', escape='\\'),
-            Span('md-strong2', 'strong', r'__', r'__', escape='\\'),
+            MDInline('md-strong1', 'strong', r'\*\*', r'\*\*|$', escape='\\'),
+            MDInline('md-strong2', 'strong', r'__', r'__|$', escape='\\'),
 
             # emphasis
-            Span('md-emphasis1', 'emphasis', r'\*', r'\*', escape='\\'),
-            Span('md-emphasis2', 'emphasis', r'_', r'_', escape='\\'),
+            MDInline('md-emphasis1', 'emphasis', r'\*', r'\*|$', escape='\\'),
+            MDInline('md-emphasis2', 'emphasis', r'_', r'_|$', escape='\\'),
 
             # code
-            Span('md-code1', 'literal', r'``', r'``', escape='\\'),
-            Span('md-code2', 'literal', r'`', r'`', escape='\\'),
+            MDInline('md-code1', 'literal', r'``', r'``', escape='\\'),
+            MDInline('md-code2', 'literal', r'`', r'`', escape='\\'),
         ))
 
 
 
+MDMENU = [
+    ['&Table of contents', None, 'toc.showlist'],
+]
+
+md_keys = {
+    (ctrl, 't'): 'toc.showlist',
+}
 
 class MarkdownMode(defaultmode.DefaultMode):
     MODENAME = 'Markdown'
+
+    def init_keybind(self):
+        super().init_keybind()
+        self.register_keys(self.keybind, [md_keys])
+
+    def init_menu(self):
+        super().init_menu()
+        self.menu['CODE'] = copy.deepcopy(MDMENU)
+
     def init_themes(self):
         super().init_themes()
         self.themes.append(MarkdownThemes)
 
     def init_tokenizers(self):
         self.tokenizers = [build_tokenizer()]
+
+    HEADER1 = r'^(?P<TITLE>.+)\n(?P<H1>[{}])(?P=H1)+$'.format(HEADERS)
+    HEADER2 = r'^(?P<H2>\#{1,6})(?P<TITLE2>.+)$'
+    
+    RE_HEADER = gre.compile('|'.join([HEADER1, HEADER2]), gre.X|gre.M)
+
+    def get_headers(self):
+        stack = []
+        pos = 0
+        while True:
+            m = self.RE_HEADER.search(self.document.buf, pos)
+            if not m:
+                break
+    
+            pos = m.end()
+            name = m.group('TITLE') or m.group('TITLE2')
+            name = name.strip()
+
+            bar = m.group('H1')
+            if bar:
+                if bar == '=':
+                    level = 0
+                else:
+                    level = 1
+            else:
+                level = len(m.group('H2'))-1
+
+            if not stack:
+                header = self.HeaderInfo('namespace', None, name, name, 
+                            None, pos)
+                yield header
+                stack.append((level, header))
+                continue
+
+            for i, (parent_level, info) in enumerate(stack):
+                if level <= parent_level:
+                    del stack[i:]
+                    break
+
+            if stack:
+                parent = stack[-1][1]
+            else:
+                parent = None
+
+            header = self.HeaderInfo(
+                'namespace', parent, name, 
+                name, None, pos)
+            yield header
+            stack.append((level, header))
+            
+
+    @command('toc.showlist')
+    @norec
+    @norerun
+    def show_toclist(self, wnd):
+        from kaa.ui.toclist import toclistmode
+        headers = list(self.get_headers())
+        toclistmode.show_toclist(wnd, headers)
+
