@@ -7,12 +7,12 @@ from kaa.filetype.default import keybind
 from kaa.ui.itemlist import itemlistmode
 
 FileInfoThemes = {
-    'default':
+    'basic':
         Theme([
             Style('button', 'Base3', 'Blue'),
             Style('shortcut', 'Base3', 'Orange', bold=True,
                   underline=True, nowrap=True),
-        ])
+        ]),
 }
 
 
