@@ -7,9 +7,9 @@ from kaa.commands import editorcommand
 from kaa.keyboard import *
 
 InputlineThemes = {
-    'default':
+    'basic':
         Theme([
-        ])
+        ]),
 }
 
 inputline_keys = {
