@@ -5,9 +5,9 @@ from kaa.theme import Theme, Style
 from kaa.keyboard import *
 
 ItemListThemes = {
-    'default':
+    'basic':
         Theme([
-        ])
+        ]),
 }
 
 itemlist_keys = {
